import org.jahia.osgi.BundleUtils
import org.osgi.service.cm.ConfigurationAdmin

/**
 * Upgrade script to automatically configure shards/replica templates and create new indexes
 */
log.info("Starting Augmented Search migration to 3.3.0");
updateCfg();


void updateCfg() {
    def configAdmin = BundleUtils.getOsgiService(ConfigurationAdmin.class, null);
    def configs = configAdmin.listConfigurations("(service.pid=org.jahia.modules.augmentedsearch)");
    if (configs != null && configs.length > 0) {
        log.info("Updating Augmented Search configuration...");
        def configuration = configs[0];
        // manually add additional configuration to upgrade existing cfg
        Dictionary<String, Object> props = configuration.getProperties();
        if (props != null) {
            putProps(props, "org.jahia.modules.augmentedsearch.numberOfShards", -1);
            putProps(props, "org.jahia.modules.augmentedsearch.numberOfReplicas", -1);
            putProps(props, "org.jahia.modules.augmentedsearch.maxShardSizeInGb", 20.0f);
            putProps(props, "org.jahia.modules.augmentedsearch.minHeapPerShardInMb", 50.0f);
            putProps(props, "org.jahia.modules.augmentedsearch.file.mappedNodeTypes", "")
            configuration.update(props);
            log.info("Augmented Search Configuration updated.");
        }
    } else {
        log.info("Could not find an existing configuration for Augmented Search, no need to migrate.")
    }
}

void putProps(Dictionary<String, Object> props, String key, Object val) {
    Object oldVal = props.get(key);
    if (oldVal == null) {
        props.put(key, val)
    }
}
